@@ -28,9 +28,11 @@
 #include "exchange-delegates.h"
 #include "exchange-delegates-user.h"
 
+#include <shell/e-shell.h>
 #include <mail/mail-ops.h>
 #include <mail/mail-send-recv.h>
 #include <mail/e-mail-local.h>
+#include <mail/e-mail-folder-utils.h>
 #include <exchange-account.h>
 #include <e2k-global-catalog.h>
 #include <e2k-marshal.h>
@@ -129,7 +131,7 @@ static void
 set_perms (GtkWidget *combobox, E2kPermissionsRole role)
 {
 	if (!is_delegate_role (role)) {
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Custom"));
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("Custom"));
 		role = EXCHANGE_DELEGATES_USER_CUSTOM;
 	}
 
@@ -173,11 +175,19 @@ map_to_full_role_name (E2kPermissionsRole role_nam)
 }
 
 static void
-em_utils_delegates_done (CamelFolder *folder, CamelMimeMessage *msg, CamelMessageInfo *info,
-		       gint queued, const gchar *appended_uid, gpointer data)
+em_utils_delegates_done (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-	camel_message_info_free (info);
-	mail_send ();
+	EShell *shell;
+	EShellBackend *shell_backend;
+	EMailSession *session;
+
+	/* XXX Dig up the EMailSession from the default EShell. */
+	shell = e_shell_get_default ();
+	shell_backend = e_shell_get_backend_by_name (shell, "mail");
+	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+
+	if (e_mail_folder_append_message_finish (CAMEL_FOLDER (source_object), res, NULL, NULL))
+		mail_send (session);
 }
 
 /**
@@ -224,7 +234,7 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 		   that the delegatee would receive */
 		_("Delegate Permissions"),
 		NULL,
-		GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK, GTK_RESPONSE_OK,
 		NULL);
@@ -287,45 +297,45 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 	gtk_label_set_justify (GTK_LABEL (contact_label), GTK_JUSTIFY_CENTER);
 	gtk_misc_set_alignment (GTK_MISC (contact_label), 0, 0.5);
 
-	calendar_perms_combobox = gtk_combo_box_new_text ();
+	calendar_perms_combobox = gtk_combo_box_text_new ();
 	gtk_widget_show (calendar_perms_combobox);
 	gtk_table_attach (GTK_TABLE (folders_table), calendar_perms_combobox, 1, 2, 0, 1,
 			  (GtkAttachOptions) (GTK_FILL),
 			  (GtkAttachOptions) (GTK_FILL), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (calendar_perms_combobox), _("None"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (calendar_perms_combobox), _("Reviewer (read-only)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (calendar_perms_combobox), _("Author (read, create)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (calendar_perms_combobox), _("Editor (read, create, edit)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (calendar_perms_combobox), _("None"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (calendar_perms_combobox), _("Reviewer (read-only)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (calendar_perms_combobox), _("Author (read, create)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (calendar_perms_combobox), _("Editor (read, create, edit)"));
 
-	task_perms_combobox = gtk_combo_box_new_text ();
+	task_perms_combobox = gtk_combo_box_text_new ();
 	gtk_widget_show (task_perms_combobox);
 	gtk_table_attach (GTK_TABLE (folders_table), task_perms_combobox, 1, 2, 1, 2,
 			  (GtkAttachOptions) (GTK_FILL),
 			  (GtkAttachOptions) (GTK_FILL), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (task_perms_combobox), _("None"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (task_perms_combobox), _("Reviewer (read-only)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (task_perms_combobox), _("Author (read, create)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (task_perms_combobox), _("Editor (read, create, edit)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (task_perms_combobox), _("None"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (task_perms_combobox), _("Reviewer (read-only)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (task_perms_combobox), _("Author (read, create)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (task_perms_combobox), _("Editor (read, create, edit)"));
 
-	inbox_perms_combobox = gtk_combo_box_new_text ();
+	inbox_perms_combobox = gtk_combo_box_text_new ();
 	gtk_widget_show (inbox_perms_combobox);
 	gtk_table_attach (GTK_TABLE (folders_table), inbox_perms_combobox, 1, 2, 2, 3,
 			  (GtkAttachOptions) (GTK_FILL),
 			  (GtkAttachOptions) (GTK_FILL), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (inbox_perms_combobox), _("None"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (inbox_perms_combobox), _("Reviewer (read-only)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (inbox_perms_combobox), _("Author (read, create)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (inbox_perms_combobox), _("Editor (read, create, edit)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (inbox_perms_combobox), _("None"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (inbox_perms_combobox), _("Reviewer (read-only)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (inbox_perms_combobox), _("Author (read, create)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (inbox_perms_combobox), _("Editor (read, create, edit)"));
 
-	contact_perms_combobox = gtk_combo_box_new_text ();
+	contact_perms_combobox = gtk_combo_box_text_new ();
 	gtk_widget_show (contact_perms_combobox);
 	gtk_table_attach (GTK_TABLE (folders_table), contact_perms_combobox, 1, 2, 3, 4,
 			  (GtkAttachOptions) (GTK_FILL),
 			  (GtkAttachOptions) (GTK_FILL), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (contact_perms_combobox), _("None"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (contact_perms_combobox), _("Reviewer (read-only)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (contact_perms_combobox), _("Author (read, create)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (contact_perms_combobox), _("Editor (read, create, edit)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (contact_perms_combobox), _("None"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (contact_perms_combobox), _("Reviewer (read-only)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (contact_perms_combobox), _("Author (read, create)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (contact_perms_combobox), _("Editor (read, create, edit)"));
 
 	delegate_mail = gtk_check_button_new_with_mnemonic (_("_Summarize permissions"));
 	gtk_widget_show (delegate_mail);
@@ -528,11 +538,12 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			}
 
 			/* Send the permissions summarizing mail */
-			out_folder = e_mail_local_get_folder (E_MAIL_FOLDER_OUTBOX);
+			out_folder = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_OUTBOX);
 			info = camel_message_info_new (NULL);
 			camel_message_info_set_flags (info, CAMEL_MESSAGE_SEEN, CAMEL_MESSAGE_SEEN);
-			mail_append_mail (out_folder, delegate_mail, info, em_utils_delegates_done, NULL);
-
+			e_mail_folder_append_message (out_folder, delegate_mail, info, 0, NULL, em_utils_delegates_done, NULL);
+			camel_message_info_free (info);
+			g_object_unref (delegate_mail);
 		}
 
 	}
